PRO DINGO3,inout,frams,deff

;Evaluation of the results of OTRACK2 (optionally revised by
;OTRIM and RECUR) to get numbers, areas, and instantaneous
;effective diameters (d_eff) of tracked objects.
;
;INPUT:  INOUT - 3-D array, result of tracking.
;OUTPUT: FRAMS - 2-D array, giving the numbers of objects (0,*)
;		 and total pixel areas of objects (1,*) in each frame.
;	 DEFF  - 1-D array with instantaneous d_effs (") of objects.
;
;March 26, 1997, Michal.

;**************** PARAMETER ********************
scale=0.062	;scale arcsec/pixel
;***********************************************

si=size(inout)
if (si(0) ne 3) or (si(1) ne 3) then begin
  print,'ERROR: Wrong input array. STOPPED (type RETALL).'
  stop
endif

n=si(2)				;number of frames
deff=reform(inout(2,*,*))	;raw set of sizes with many zeros
				; (2-D: (frames, objects))
frams=fltarr(2,n)

for i=0,n-1 do begin		;loop over frames
   w=where(deff(i,*),c)		;c = number of objects in frame
   frams(0,i)=c
   frams(1,i)=total(deff(i,*))	;areas in pixels
endfor

w=where(deff,c)			;1-D index list of nonzero sizes
deff=deff(w)			;zero sizes discarded, -> 1-D array
deff=scale*sqrt(4*deff/!pi)	;scaling to arcsecs
print,c,' instantaneous observations of objects'

END
