PRO anal_bat,day,num,mu
;
; Batch routine for color-temperature analysis of SST 2003 data.
; DAY = 16, 19, 20
; NUM = frame number
; MU  = heliocentric position
; Output - in a save file
;

if n_params() ne 3 then begin
  print,' USAGE: anal_bat, day, frame_num, mu'
  goto,fin
endif

name=''
read,' Name of the i/o save file: ',name
print,' Set color table to RED TEMPERATURE, top=90, gamma=0.6'
window,0
xloadct,/block

print,' Background already done ? (y/n)'
if get_kbrd(1) eq 'y' then restore,name else begin
  print,' Background: Use box size = 10'
  BACKGR,day,num,gc,c6,basg,basc
  print,''
  print,' Background OK ? (y/n)'
  if get_kbrd(1) eq 'n' then goto,fin
  save,gc,c6,basg,basc,file=name
  wdelete,0,2
endelse

print,''
print,' Segmentation'
print,' Mask already done ? (y/n)'
if get_kbrd(1) eq 'y' then begin
  restore,name
  UDSEGM,gc,c6,basg,basc,tug,tuc,mask
endif else begin
  UDSEGM,gc,c6,basg,basc,tug,tuc
  restore,'mask'
  save,gc,c6,basg,basc,mask,file=name
endelse
print,' Press any key to continue'
blb=get_kbrd(1)
window,0
histy,tug(3,*),bin=5,min=0.0001,/abs
histy,tuc(3,*),bin=5,min=0.0001,/abs,/over
print,''
print,' Check histograms of areas. If they are too different,'
print,' quit now, change smoothing in udsegm.pro and recompile.'
print,' Background and mask are saved in ',name
print,' Quit now ? (y/n)'
if get_kbrd(1) eq 'y' then goto,fin

print,''
print,' Color temperature calculation'
COLTEMP,tug,tuc,mu,tru
save,gc,c6,basg,basc,mask,tug,tuc,tru,file=name
print,' UD Results saved in ',name

wset,2
ocont,gc-basg,gc-basg,[-501,-500]
ocont,gc-basg,gc-basg,[-501,-500]
oplot,tru(0,*),tru(1,*),psym=1
wset,0
plot,tru(4,*),tru(8,*),psym=1,title='Intensities UD vs. DB, 4507'
oplot,tru(4,*),tru(2,*),psym=1,col=100
print,' Press any key to continue'
blb=get_kbrd(1)
plot,tru(5,*),tru(9,*),psym=1,title='Intensities UD vs. DB, 6020'
oplot,tru(5,*),tru(3,*),psym=1,col=100
print,' Press any key to continue'
blb=get_kbrd(1)
print,' Observed diameters'
histy,tru(10,*),bin=0.04,min=0.0001,/abs
histy,tru(11,*),bin=0.04,min=0.0001,/abs,/over
print,' Press any key to continue'
blb=get_kbrd(1)
print,' True diameters'
histy,tru(12,*),bin=0.04,min=0.0001,/abs
print,' Press any key to continue'
blb=get_kbrd(1)
print,' Temperatures'
histy,tru(7,*),bin=200,min=4000,/abs

; Minimum umbral intensities and temperatures

umig=min(gc)/10000.
umic=min(c6)/10000.
bmig=min(basg)/10000.
bmic=min(basc)/10000.
tu=TEPLOTA(umig,umic,mu)
tb=TEPLOTA(bmig,bmic,mu)
print,' Darkest point in the umbra (Igc, Ic6, Tgc, Tc6, Tcol):'
print,umig,umic,tu
print,' Darkest point in the background (Igc, Ic6, Tgc, Tc6, Tcol):'
print,bmig,bmic,tb
save,umig,umic,tu,bmig,bmic,tb,file=name+'_umb'
print,' Darkest point results saved in ',name+'_umb'

fin:
print,''
print,'ANAL_BAT finished'

END

