PRO remove_bad,day,type
;
; Flatfielded and normalized frames are selected according to a
; given criterion, bad frames are moved to the directory "rejected"
; and a new logfile type_day'selg' without these frames is made.
; INPUTS: day   = date (14,16,18,19,20)
;	  type  = channel ('gc' or 'ca')
;	  logfile (0 - seq. no., 1 - UT, 2 - SST sharpness, 5 - contrast) 
; OUTPUT: *selg.sav2 and *selg.txt files with the new logfile
; NOTE: Since 'gc' is the master, 'c6' frames are processed
;	simultaneously with 'gc'
; SUBROUTINE: wrilogtxt

sday=strtrim(fix(day),2)

;paths and names

pa1='/scratch1/sobotka/lap2003/images_ffn/'
pa2=type+'_'+sday+'/'
rejpa='/scratch1/sobotka/lap2003/rejected/'

lgfil=pa1+pa2+type+'_'+sday+'lg.sav2'	;original logfile
selgfil=pa1+pa2+type+'_'+sday+'selg'	;new logfile
fil=pa1+pa2+type+'_'+sday+'ffn.'	;frame name

restore2,lgfil,log			;read orig. logfile
sl=size(log)
nr=0					;nr = no. of rejected frames
nk=sl(2)				;nk = no. of kept frames

if type eq 'gc' then begin

  c6fil=pa1+'c6_'+sday+'/c6_'+sday+'ffn.'
  c6lgfil=pa1+'c6_'+sday+'/c6_'+sday+'lg.sav2'
  c6selgfil=pa1+'c6_'+sday+'/c6_'+sday+'selg'
 
  ;******** CRITERION GC and C6 **********
  ; 1. SST sharpness < 3500  AND
  ; 2. RMS granular contrast < 4.5 %

  w   =where((log(2,*) lt 3500 and log(5,*) lt 0.045),nr)
  notw=where((log(2,*) ge 3500 or  log(5,*) ge 0.045),nk)
  
  ;***************************************
  
endif

if type eq 'ca' then begin

  ;******** CRITERION Ca II H ************
  ; SST sharpness < 2726
  
  w   =where((log(2,*) lt 2726),nr)
  notw=where((log(2,*) ge 2726),nk)

  ;***************************************
  
endif

print,' Rejected:',nr,'    Kept:',nk,'    Total:',sl(2)
if nr eq 0 then goto,fin	;no bad frames found

; list of bad frame numbers is in log(0,w)

window,0,xs=1000,ys=600		;quality plots
!p.multi=[0,0,2,0,0]
plot,log(0,*),log(2,*),psym=1,symsiz=0.5,xtitle='Frame',ytitle='SST Sharpness'
oplot,log(0,w),log(2,w),psym=6,symsiz=0.8
plot,log(0,*),log(5,*),psym=1,symsiz=0.5,xtitle='Frame',ytitle='RMS Contrast'
oplot,log(0,w),log(5,w),psym=6,symsiz=0.8

print,'**** OK ? (y/n) ****'
if get_kbrd(1) ne 'y' then goto,fin

; LOOP over frames - moving bad ones to rejected/

for i=0,nr-1 do begin

  stnum = string(fix(log(0,w(i))),format='(I4.4)')
  print,' Moving  ',stnum,'  to rejected/'
  
  if type eq 'gc' then begin
      str1='mv '+fil+stnum+' '+rejpa
      spawn,str1
      str2='mv '+c6fil+stnum+' '+rejpa
      spawn,str2
  endif

  if type eq 'ca' then begin    
      str='mv '+fil+stnum+' '+rejpa
      spawn,str
  endif

endfor

; END_OF_LOOP

; Making new logfile(s)

if type eq 'gc' then begin
  newlog=log(*,notw)
  restore2,c6lgfil,c6log
  newc6log=c6log(*,notw)
  print,' Writing new logfile: ',selgfil
  print,' Writing new logfile: ',c6selgfil
  wrilogtxt,selgfil,newlog
  wrilogtxt,c6selgfil,newc6log
endif

if type eq 'ca' then begin
  newlog=log(*,notw)
  print,' Writing new logfile: ',selgfil
  wrilogtxt,selgfil,newlog
endif

; Check if new logs are ok
plot,log(0,*),log(2,*),psym=1,symsiz=0.5,xtitle='Frame',ytitle='SST Sharpness'
oplot,newlog(0,*),newlog(2,*),psym=6,symsiz=0.8
plot,log(0,*),log(5,*),psym=1,symsiz=0.5,xtitle='Frame',ytitle='RMS Contrast'
oplot,newlog(0,*),newlog(5,*),psym=6,symsiz=0.8
!p.multi=0

fin:
END
